function [negentropy_vs_rotation_allpairs, rotation_angles, pairs] = negentropy_vs_rotation(W)

% Calculates negentropy for all pairs of rows of the matrix W, as a function of their "rotation"
% Plots the negentropy vs. rotation function for all pairs
% 
% -- Outputs --
% 
% negentropy_vs_rotation_allpairs: rotation-angle x pair matrix
% 
% rotation_angles: corresponding rotation angles in radians
% 
% pairs: corresponding angles

% ensures rows of W have unit variance
W = zscore(W')';

% entropy of a gaussian with unit variance
gaussEntropy = log(sqrt(2*pi*exp(1)));

% rotations to search over
step_size_in_radians = pi/128;
rotation_angles = -pi/4 : step_size_in_radians : pi/4;

% compute negentropy
n_components = size(W,1);
pairs = flipud(combnk(1:n_components,2));
n_pairs = size(pairs,1);
negentropy_vs_rotation_allpairs = nan(length(rotation_angles), n_pairs);
for i = 1:size(pairs,1) % loop through all pairs
    for j = 1:length(rotation_angles) % loop through rotation angles
        
        % rotate the pair
        rotated_pair = rotMat2D(rotation_angles(j)) * W(pairs(i,:),:);
        
        % measure the summed negentropy
        negentropy_vs_rotation_allpairs(j,i) = sum(gaussEntropy - [entropy(rotated_pair(1,:)), entropy(rotated_pair(2,:))]);
        
    end
end

% plot negentropy vs. rotation
plot(rotation_angles/pi, negentropy_vs_rotation_allpairs, 'LineWidth', 2);
xlabel('Rotation (Pi Radians)'); ylabel('Negentropy');
xlim([-0.25 0.25]);
ylim([0 max(negentropy_vs_rotation_allpairs(:))*1.1]);
drawnow;



